@@ -22,10 +22,14 @@
 
 #include <glib.h>
 
+#include <gconf/gconf-glib-public.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
+#define GCONF_ERROR gconf_error_quark ()
+
 /* Error Numbers */
 
 /* Sync with ConfigErrorType in GConf.idl */
@@ -47,36 +51,11 @@ typedef enum {
   GCONF_ERROR_OVERRIDDEN = 11,   /* Read-only source at front of path has set the value */
   GCONF_ERROR_OAF_ERROR = 12,    /* liboaf error */
   GCONF_ERROR_LOCAL_ENGINE = 13, /* Tried to use remote operations on a local engine */
-  GCONF_ERROR_LOCK_FAILED = 14   /* Failed to get a lockfile */
-} GConfErrNo;
+  GCONF_ERROR_LOCK_FAILED = 14,  /* Failed to get a lockfile */
+  GCONF_ERROR_NO_WRITABLE_DATABASE = 14 /* nowhere to write a value */
+} GConfError;
 
-/* Error Object */
-
-typedef struct _GConfError GConfError;
-
-struct _GConfError {
-  const gchar* str; /* combination of strerror of the num and additional
-                       details; a complete error message. */
-  GConfErrNo num;
-};
-
-GConfError*  gconf_error_new      (GConfErrNo en, const gchar* format, ...) G_GNUC_PRINTF (2, 3);
-GConfError*  gconf_error_copy     (GConfError* err);
-void         gconf_error_destroy  (GConfError* err);
-
-/* if (err) *err = gconf_error_new(en, format, ...), also has some sanity checks. */
-void         gconf_set_error      (GConfError** err, GConfErrNo en, const gchar* format, ...) G_GNUC_PRINTF (3, 4);
-
-/* if (err && *err) { gconf_error_destroy(*err); *err = NULL; } */
-void         gconf_clear_error    (GConfError** err);
-
-/* merge two errors into a single message */
-GConfError*  gconf_compose_errors (GConfError* err1, GConfError* err2);
-
-/* strerror() really shouldn't be used, because GConfError->str gives
- * a more complete error message.
- */
-const gchar* gconf_strerror       (GConfErrNo en);
+GQuark gconf_error_quark (void);
 
 #ifdef __cplusplus
 }
