@@ -37,21 +37,6 @@
 #include <time.h>
 #include <math.h>
 
-
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
 static gboolean gconf_daemon_mode = FALSE;
 static gchar* daemon_ior = NULL;
 
@@ -246,7 +231,7 @@ gconf_value_from_corba_value(const ConfigValue* value)
             break;
           }
 
-        if (gconf_value_list_type(gval) != GCONF_VALUE_INVALID)
+        if (gconf_value_get_list_type(gval) != GCONF_VALUE_INVALID)
           {
             i = 0;
             while (i < value->_u.list_value.seq._length)
@@ -262,7 +247,7 @@ gconf_value_from_corba_value(const ConfigValue* value)
                 
                 if (val == NULL)
                   gconf_log(GCL_ERR, _("Couldn't interpret CORBA value for list element"));
-                else if (val->type != gconf_value_list_type(gval))
+                else if (val->type != gconf_value_get_list_type(gval))
                   gconf_log(GCL_ERR, _("Incorrect type for list element in %s"), __FUNCTION__);
                 else
                   list = g_slist_prepend(list, val);
@@ -313,23 +298,23 @@ fill_corba_value_from_gconf_value(GConfValue* value,
     {
     case GCONF_VALUE_INT:
       cv->_d = IntVal;
-      cv->_u.int_value = gconf_value_int(value);
+      cv->_u.int_value = gconf_value_get_int(value);
       break;
     case GCONF_VALUE_STRING:
       cv->_d = StringVal;
-      cv->_u.string_value = CORBA_string_dup((char*)gconf_value_string(value));
+      cv->_u.string_value = CORBA_string_dup((char*)gconf_value_get_string(value));
       break;
     case GCONF_VALUE_FLOAT:
       cv->_d = FloatVal;
-      cv->_u.float_value = gconf_value_float(value);
+      cv->_u.float_value = gconf_value_get_float(value);
       break;
     case GCONF_VALUE_BOOL:
       cv->_d = BoolVal;
-      cv->_u.bool_value = gconf_value_bool(value);
+      cv->_u.bool_value = gconf_value_get_bool(value);
       break;
     case GCONF_VALUE_SCHEMA:
       cv->_d = SchemaVal;
-      fill_corba_schema_from_gconf_schema(gconf_value_schema(value),
+      fill_corba_schema_from_gconf_schema(gconf_value_get_schema(value),
                                            &cv->_u.schema_value);
       break;
     case GCONF_VALUE_LIST:
@@ -339,7 +324,7 @@ fill_corba_value_from_gconf_value(GConfValue* value,
         
         cv->_d = ListVal;
 
-        list = gconf_value_list(value);
+        list = gconf_value_get_list(value);
 
         n = g_slist_length(list);
 
@@ -349,7 +334,7 @@ fill_corba_value_from_gconf_value(GConfValue* value,
         cv->_u.list_value.seq._maximum = n;
         CORBA_sequence_set_release(&cv->_u.list_value.seq, TRUE);
         
-        switch (gconf_value_list_type(value))
+        switch (gconf_value_get_list_type(value))
           {
           case GCONF_VALUE_INT:
             cv->_u.list_value.list_type = BIntVal;
@@ -400,9 +385,9 @@ fill_corba_value_from_gconf_value(GConfValue* value,
         CORBA_sequence_set_release(&cv->_u.pair_value, TRUE);
         
         /* dubious cast */
-        fill_corba_value_from_gconf_value(gconf_value_car(value),
+        fill_corba_value_from_gconf_value(gconf_value_get_car(value),
                                            (ConfigValue*)&cv->_u.pair_value._buffer[0]);
-        fill_corba_value_from_gconf_value(gconf_value_cdr(value),
+        fill_corba_value_from_gconf_value(gconf_value_get_cdr(value),
                                            (ConfigValue*)&cv->_u.pair_value._buffer[1]);
       }
       break;
@@ -441,6 +426,34 @@ invalid_corba_value()
   return cv;
 }
 
+gchar*
+gconf_object_to_string (CORBA_Object obj,
+                        GError **err)
+{
+  CORBA_Environment ev;
+  gchar *ior;
+  gchar *retval;
+  
+  CORBA_exception_init (&ev);
+
+  ior = CORBA_ORB_object_to_string (oaf_orb_get (), obj, &ev);
+
+  if (ior == NULL)
+    {
+      gconf_set_error (err,
+                       GCONF_ERROR_FAILED,
+                       _("Failed to convert object to IOR"));
+
+      return NULL;
+    }
+
+  retval = g_strdup (ior);
+
+  CORBA_free (ior);
+
+  return retval;
+}
+
 static ConfigValueType
 corba_type_from_gconf_type(GConfValueType type)
 {
@@ -513,7 +526,7 @@ fill_corba_schema_from_gconf_schema(GConfSchema* sc,
     gchar* encoded;
     GConfValue* default_val;
 
-    default_val = gconf_schema_default_value(sc);
+    default_val = gconf_schema_get_default_value(sc);
 
     if (default_val)
       {
@@ -780,7 +793,7 @@ subst_variables(const gchar* src)
 }
 
 gchar**       
-gconf_load_source_path(const gchar* filename, GConfError** err)
+gconf_load_source_path(const gchar* filename, GError** err)
 {
   FILE* f;
   GSList* l = NULL;
@@ -906,7 +919,7 @@ gconf_load_source_path(const gchar* filename, GConfError** err)
    or dir and subdir.
 */
 gchar*        
-gconf_concat_key_and_dir(const gchar* dir, const gchar* key)
+gconf_concat_dir_and_key(const gchar* dir, const gchar* key)
 {
   guint dirlen;
   guint keylen;
@@ -1290,7 +1303,7 @@ gconf_value_pair_from_primitive_pair(GConfValueType car_type,
 GSList*
 gconf_value_list_to_primitive_list_destructive(GConfValue* val,
                                                GConfValueType list_type,
-                                               GConfError** err)
+                                               GError** err)
 {
   GSList* retval;
 
@@ -1306,30 +1319,30 @@ gconf_value_list_to_primitive_list_destructive(GConfValue* val,
         *err = gconf_error_new(GCONF_ERROR_TYPE_MISMATCH,
                                _("Expected list, got %s"),
                                gconf_value_type_to_string(val->type));
-      gconf_value_destroy(val);
+      gconf_value_free(val);
       return NULL;
     }
 
-  if (gconf_value_list_type(val) != list_type)
+  if (gconf_value_get_list_type(val) != list_type)
     {
       if (err)
         *err = gconf_error_new(GCONF_ERROR_TYPE_MISMATCH,
                                _("Expected list of %s, got list of %s"),
                                gconf_value_type_to_string(list_type),
                                gconf_value_type_to_string(val->type));
-      gconf_value_destroy(val);
+      gconf_value_free(val);
       return NULL;
     }
 
-  g_assert(gconf_value_list_type(val) == list_type);
+  g_assert(gconf_value_get_list_type(val) == list_type);
       
-  retval = gconf_value_list(val);
+  retval = gconf_value_get_list(val);
 
   /* Cheating the API to avoid a list copy; set this to NULL to
          avoid destroying the list */
   val->d.list_data.list = NULL;
       
-  gconf_value_destroy(val);
+  gconf_value_free(val);
   val = NULL;
       
   {
@@ -1349,13 +1362,13 @@ gconf_value_list_to_primitive_list_destructive(GConfValue* val,
           {
           case GCONF_VALUE_INT:
           case GCONF_VALUE_BOOL:
-            tmp->data = GINT_TO_POINTER(gconf_value_int(elem));
+            tmp->data = GINT_TO_POINTER(gconf_value_get_int(elem));
             break;
                 
           case GCONF_VALUE_FLOAT:
             {
               gdouble* d = g_new(gdouble, 1);
-              *d = gconf_value_float(elem);
+              *d = gconf_value_get_float(elem);
               tmp->data = d;
             }
             break;
@@ -1382,7 +1395,7 @@ gconf_value_list_to_primitive_list_destructive(GConfValue* val,
           }
 
         /* Clean up the value */
-        gconf_value_destroy(elem);
+        gconf_value_free(elem);
             
         tmp = g_slist_next(tmp);
       }
@@ -1398,11 +1411,11 @@ primitive_value(gpointer retloc, GConfValue* val)
   switch (val->type)
     {
     case GCONF_VALUE_INT:
-      *((gint*)retloc) = gconf_value_int(val);
+      *((gint*)retloc) = gconf_value_get_int(val);
       break;
 
     case GCONF_VALUE_FLOAT:
-      *((gdouble*)retloc) = gconf_value_float(val);
+      *((gdouble*)retloc) = gconf_value_get_float(val);
       break;
 
     case GCONF_VALUE_STRING:
@@ -1414,11 +1427,11 @@ primitive_value(gpointer retloc, GConfValue* val)
       break;
 
     case GCONF_VALUE_BOOL:
-      *((gboolean*)retloc) = gconf_value_bool(val);
+      *((gboolean*)retloc) = gconf_value_get_bool(val);
       break;
 
     case GCONF_VALUE_SCHEMA:
-      *((GConfSchema**)retloc) = gconf_value_schema(val);
+      *((GConfSchema**)retloc) = gconf_value_get_schema(val);
       break;
       
     default:
@@ -1433,7 +1446,7 @@ gconf_value_pair_to_primitive_pair_destructive(GConfValue* val,
                                                GConfValueType cdr_type,
                                                gpointer car_retloc,
                                                gpointer cdr_retloc,
-                                               GConfError** err)
+                                               GError** err)
 {
   GConfValue* car;
   GConfValue* cdr;
@@ -1455,12 +1468,12 @@ gconf_value_pair_to_primitive_pair_destructive(GConfValue* val,
         *err = gconf_error_new(GCONF_ERROR_TYPE_MISMATCH,
                                _("Expected pair, got %s"),
                                gconf_value_type_to_string(val->type));
-      gconf_value_destroy(val);
+      gconf_value_free(val);
       return FALSE;
     }
 
-  car = gconf_value_car(val);
-  cdr = gconf_value_cdr(val);
+  car = gconf_value_get_car(val);
+  cdr = gconf_value_get_cdr(val);
       
   if (car == NULL ||
       cdr == NULL)
@@ -1471,7 +1484,7 @@ gconf_value_pair_to_primitive_pair_destructive(GConfValue* val,
                                gconf_value_type_to_string(car_type),
                                gconf_value_type_to_string(cdr_type));
 
-      gconf_value_destroy(val);
+      gconf_value_free(val);
       return FALSE;
     }
 
@@ -1488,14 +1501,14 @@ gconf_value_pair_to_primitive_pair_destructive(GConfValue* val,
                                gconf_value_type_to_string(cdr_type),
                                gconf_value_type_to_string(car->type),
                                gconf_value_type_to_string(cdr->type));
-      gconf_value_destroy(val);
+      gconf_value_free(val);
       return FALSE;
     }
 
   primitive_value(car_retloc, car);
   primitive_value(cdr_retloc, cdr);
 
-  gconf_value_destroy(val);
+  gconf_value_free(val);
 
   return TRUE;
 }
@@ -1565,7 +1578,7 @@ gconf_quote_string   (const gchar* src)
 }
 
 gchar*
-gconf_unquote_string (const gchar* str, const gchar** end, GConfError** err)
+gconf_unquote_string (const gchar* str, const gchar** end, GError** err)
 {
   gchar* unq;
   gchar* unq_end = NULL;
@@ -1584,7 +1597,7 @@ gconf_unquote_string (const gchar* str, const gchar** end, GConfError** err)
 }
 
 void
-gconf_unquote_string_inplace (gchar* str, gchar** end, GConfError** err)
+gconf_unquote_string_inplace (gchar* str, gchar** end, GError** err)
 {
   gchar* dest;
   gchar* s;
@@ -1987,19 +2000,19 @@ gconf_value_encode (GConfValue* val)
   switch (val->type)
     {
     case GCONF_VALUE_INT:
-      retval = g_strdup_printf("i%d", gconf_value_int(val));
+      retval = g_strdup_printf("i%d", gconf_value_get_int(val));
       break;
         
     case GCONF_VALUE_BOOL:
-      retval = g_strdup_printf("b%c", gconf_value_bool(val) ? 't' : 'f');
+      retval = g_strdup_printf("b%c", gconf_value_get_bool(val) ? 't' : 'f');
       break;
 
     case GCONF_VALUE_FLOAT:
-      retval = g_strdup_printf("f%g", gconf_value_float(val));
+      retval = g_strdup_printf("f%g", gconf_value_get_float(val));
       break;
 
     case GCONF_VALUE_STRING:
-      retval = g_strdup_printf("s%s", gconf_value_string(val));
+      retval = g_strdup_printf("s%s", gconf_value_get_string(val));
       break;
 
     case GCONF_VALUE_SCHEMA:
@@ -2010,24 +2023,24 @@ gconf_value_encode (GConfValue* val)
         gchar* encoded;
         GConfSchema* sc;
 
-        sc = gconf_value_schema(val);
+        sc = gconf_value_get_schema(val);
         
         tmp = g_strdup_printf("c%c%c%c%c,",
-			      type_byte(gconf_schema_type(sc)),
-			      type_byte(gconf_schema_list_type(sc)),
-			      type_byte(gconf_schema_car_type(sc)),
-			      type_byte(gconf_schema_cdr_type(sc)));
+			      type_byte(gconf_schema_get_type(sc)),
+			      type_byte(gconf_schema_get_list_type(sc)),
+			      type_byte(gconf_schema_get_car_type(sc)),
+			      type_byte(gconf_schema_get_cdr_type(sc)));
 
-        quoted = gconf_quote_string(gconf_schema_locale(sc) ?
-                                    gconf_schema_locale(sc) : "");
+        quoted = gconf_quote_string(gconf_schema_get_locale(sc) ?
+                                    gconf_schema_get_locale(sc) : "");
         retval = g_strconcat(tmp, quoted, ",", NULL);
 
         g_free(tmp);
         g_free(quoted);
 
         tmp = retval;
-        quoted = gconf_quote_string(gconf_schema_short_desc(sc) ?
-                                    gconf_schema_short_desc(sc) : "");
+        quoted = gconf_quote_string(gconf_schema_get_short_desc(sc) ?
+                                    gconf_schema_get_short_desc(sc) : "");
 
         retval = g_strconcat(tmp, quoted, ",", NULL);
 
@@ -2036,8 +2049,8 @@ gconf_value_encode (GConfValue* val)
 
 
         tmp = retval;
-        quoted = gconf_quote_string(gconf_schema_long_desc(sc) ?
-                                    gconf_schema_long_desc(sc) : "");
+        quoted = gconf_quote_string(gconf_schema_get_long_desc(sc) ?
+                                    gconf_schema_get_long_desc(sc) : "");
 
         retval = g_strconcat(tmp, quoted, ",", NULL);
 
@@ -2045,8 +2058,8 @@ gconf_value_encode (GConfValue* val)
         g_free(quoted);
         
 
-        if (gconf_schema_default_value(sc) != NULL)
-          encoded = gconf_value_encode(gconf_schema_default_value(sc));
+        if (gconf_schema_get_default_value(sc) != NULL)
+          encoded = gconf_value_encode(gconf_schema_get_default_value(sc));
         else
           encoded = g_strdup("");
 
@@ -2066,9 +2079,9 @@ gconf_value_encode (GConfValue* val)
       {
         GSList* tmp;
 
-        retval = g_strdup_printf("l%c", type_byte(gconf_value_list_type(val)));
+        retval = g_strdup_printf("l%c", type_byte(gconf_value_get_list_type(val)));
         
-        tmp = gconf_value_list(val);
+        tmp = gconf_value_get_list(val);
 
         while (tmp != NULL)
           {
@@ -2106,8 +2119,8 @@ gconf_value_encode (GConfValue* val)
         gchar* car_quoted;
         gchar* cdr_quoted;
 
-        car_encoded = gconf_value_encode(gconf_value_car(val));
-        cdr_encoded = gconf_value_encode(gconf_value_cdr(val));
+        car_encoded = gconf_value_encode(gconf_value_get_car(val));
+        cdr_encoded = gconf_value_encode(gconf_value_get_cdr(val));
 
         car_quoted = gconf_quote_string(car_encoded);
         cdr_quoted = gconf_quote_string(cdr_encoded);
@@ -2131,7 +2144,7 @@ gconf_value_encode (GConfValue* val)
 }
 
 gboolean
-gconf_handle_oaf_exception(CORBA_Environment* ev, GConfError** err)
+gconf_handle_oaf_exception(CORBA_Environment* ev, GError** err)
 {
   switch (ev->_major)
     {
@@ -2156,7 +2169,9 @@ gconf_handle_oaf_exception(CORBA_Environment* ev, GConfError** err)
             OAF_GeneralError* ge = CORBA_exception_value(ev);
 
             if (err)
-              *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("%s"), ge->description);
+              *err = gconf_error_new(GCONF_ERROR_OAF_ERROR,
+                                     _("OAF problem description: '%s'"),
+                                     ge->description);
           }
         else if (strcmp(id,"IDL:OAF/ActivationContext/NotListed:1.0" ) == 0)
           {
@@ -2234,7 +2249,7 @@ gconf_lock_destroy(GConfLock* lock)
 
 GConfLock*
 gconf_get_lock(const gchar* lock_directory,
-               GConfError** err)
+               GError** err)
 {
   GConfLock* lock;
   gboolean got_it = FALSE;
@@ -2467,7 +2482,7 @@ gconf_get_lock(const gchar* lock_directory,
 
 gboolean
 gconf_release_lock(GConfLock* lock,
-                   GConfError** err)
+                   GError** err)
 {
   gchar* iorfile;
   FILE* fp;
