@@ -22,6 +22,7 @@
 #include "gconf-sources.h"
 #include "gconf-internals.h"
 #include "gconf-schema.h"
+#include "gconf.h"
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -32,27 +33,12 @@
 #include <errno.h>
 #include <ctype.h>
 
-
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
 /* 
  *  Sources
  */
 
 GConfSource* 
-gconf_resolve_address(const gchar* address, GConfError** err)
+gconf_resolve_address(const gchar* address, GError** err)
 {
   GConfBackend* backend;
 
@@ -84,7 +70,7 @@ gconf_resolve_address(const gchar* address, GConfError** err)
 }
 
 void         
-gconf_source_destroy (GConfSource* source)
+gconf_source_free (GConfSource* source)
 {
   GConfBackend* backend;
   
@@ -104,14 +90,14 @@ gconf_source_destroy (GConfSource* source)
         (*(source)->backend->vtable->readable)((source), (key), (err))) )
 
 static gboolean
-source_is_writeable(GConfSource* source, const gchar* key, GConfError** err)
+source_is_writable(GConfSource* source, const gchar* key, GError** err)
 {
   if ((source->flags & GCONF_SOURCE_NEVER_WRITEABLE) != 0)
     return FALSE;
   else if ((source->flags & GCONF_SOURCE_ALL_WRITEABLE) != 0)
     return TRUE;
-  else if (source->backend->vtable->writeable != NULL &&
-           (*source->backend->vtable->writeable)(source, key, err))
+  else if (source->backend->vtable->writable != NULL &&
+           (*source->backend->vtable->writable)(source, key, err))
     return TRUE;
   else
     return FALSE;
@@ -122,7 +108,7 @@ gconf_source_query_value      (GConfSource* source,
                                const gchar* key,
                                const gchar** locales,
                                gchar** schema_name,
-                               GConfError** err)
+                               GError** err)
 {
   g_return_val_if_fail(source != NULL, NULL);
   g_return_val_if_fail(key != NULL, NULL);
@@ -142,7 +128,7 @@ gconf_source_query_value      (GConfSource* source,
 static GConfMetaInfo*
 gconf_source_query_metainfo      (GConfSource* source,
                                   const gchar* key,
-                                  GConfError** err)
+                                  GError** err)
 {
   g_return_val_if_fail(source != NULL, NULL);
   g_return_val_if_fail(key != NULL, NULL);
@@ -160,12 +146,12 @@ gconf_source_query_metainfo      (GConfSource* source,
 }
 
 
-/* return value indicates whether the key was writeable */
+/* return value indicates whether the key was writable */
 static gboolean
 gconf_source_set_value        (GConfSource* source,
                                const gchar* key,
                                GConfValue* value,
-                               GConfError** err)
+                               GError** err)
 {
   g_return_val_if_fail(source != NULL, FALSE);
   g_return_val_if_fail(value != NULL, FALSE);
@@ -174,7 +160,7 @@ gconf_source_set_value        (GConfSource* source,
   
   /* don't check key validity */
 
-  if ( source_is_writeable(source, key, err) )
+  if ( source_is_writable(source, key, err) )
     {
       g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
       (*source->backend->vtable->set_value)(source, key, value, err);
@@ -188,15 +174,16 @@ static gboolean
 gconf_source_unset_value      (GConfSource* source,
                                const gchar* key,
                                const gchar* locale,
-                               GConfError** err)
+                               GError** err)
 {
   g_return_val_if_fail(source != NULL, FALSE);
   g_return_val_if_fail(key != NULL, FALSE);
   g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
   
-  if ( source_is_writeable(source, key, err) )
+  if ( source_is_writable(source, key, err) )
     {
       g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
+
       (*source->backend->vtable->unset_value)(source, key, locale, err);
       return TRUE;
     }
@@ -208,7 +195,7 @@ static GSList*
 gconf_source_all_entries         (GConfSource* source,
                                   const gchar* dir,
                                   const gchar** locales,
-                                  GConfError** err)
+                                  GError** err)
 {
   g_return_val_if_fail(source != NULL, NULL);
   g_return_val_if_fail(dir != NULL, NULL);
@@ -226,7 +213,7 @@ gconf_source_all_entries         (GConfSource* source,
 static GSList*      
 gconf_source_all_dirs          (GConfSource* source,
                                 const gchar* dir,
-                                GConfError** err)
+                                GError** err)
 {
   g_return_val_if_fail(source != NULL, NULL);
   g_return_val_if_fail(dir != NULL, NULL);  
@@ -244,7 +231,7 @@ gconf_source_all_dirs          (GConfSource* source,
 static gboolean
 gconf_source_dir_exists        (GConfSource* source,
                                 const gchar* dir,
-                                GConfError** err)
+                                GError** err)
 {
   g_return_val_if_fail(source != NULL, FALSE);
   g_return_val_if_fail(dir != NULL, FALSE);
@@ -262,13 +249,13 @@ gconf_source_dir_exists        (GConfSource* source,
 static void         
 gconf_source_remove_dir        (GConfSource* source,
                                 const gchar* dir,
-                                GConfError** err)
+                                GError** err)
 {
   g_return_if_fail(source != NULL);
   g_return_if_fail(dir != NULL);
   g_return_if_fail(err == NULL || *err == NULL);
   
-  if ( source_is_writeable(source, dir, err) )
+  if ( source_is_writable(source, dir, err) )
     {
       g_return_if_fail(err == NULL || *err == NULL);
       (*source->backend->vtable->remove_dir)(source, dir, err);
@@ -279,14 +266,14 @@ static gboolean
 gconf_source_set_schema        (GConfSource* source,
                                 const gchar* key,
                                 const gchar* schema_key,
-                                GConfError** err)
+                                GError** err)
 {
   g_return_val_if_fail(source != NULL, FALSE);
   g_return_val_if_fail(key != NULL, FALSE);
   g_return_val_if_fail(schema_key != NULL, FALSE);
   g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
   
-  if ( source_is_writeable(source, key, err) )
+  if ( source_is_writable(source, key, err) )
     {
       g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
       (*source->backend->vtable->set_schema)(source, key, schema_key, err);
@@ -297,7 +284,7 @@ gconf_source_set_schema        (GConfSource* source,
 }
 
 static gboolean
-gconf_source_sync_all         (GConfSource* source, GConfError** err)
+gconf_source_sync_all         (GConfSource* source, GError** err)
 {
   return (*source->backend->vtable->sync_all)(source, err);
 }
@@ -307,10 +294,9 @@ gconf_source_sync_all         (GConfSource* source, GConfError** err)
  */
 
 GConfSources* 
-gconf_sources_new_from_addresses(const gchar** addresses, GConfError** err)
+gconf_sources_new_from_addresses(const gchar** addresses, GError** err)
 {
   GConfSources* sources;
-  gboolean errors_occurred = FALSE;
 
   g_return_val_if_fail( (err == NULL) || (*err == NULL), NULL);
   
@@ -319,7 +305,7 @@ gconf_sources_new_from_addresses(const gchar** addresses, GConfError** err)
   while (*addresses != NULL)
     {
       GConfSource* source;
-      GConfError* error = NULL;
+      GError* error = NULL;
       
       source = gconf_resolve_address(*addresses, &error);
 
@@ -332,9 +318,9 @@ gconf_sources_new_from_addresses(const gchar** addresses, GConfError** err)
         {
           g_assert(error != NULL);
           gconf_log(GCL_WARNING, _("Failed to load source `%s': %s"),
-                    *addresses, error->str);
+                    *addresses, error->message);
           
-          gconf_error_destroy(error);
+          g_error_free(error);
         }
           
       ++addresses;
@@ -358,7 +344,7 @@ gconf_sources_new_from_source       (GConfSource* source)
 }
 
 void
-gconf_sources_destroy(GConfSources* sources)
+gconf_sources_free(GConfSources* sources)
 {
   GList* tmp;
 
@@ -366,7 +352,7 @@ gconf_sources_destroy(GConfSources* sources)
 
   while (tmp != NULL)
     {
-      gconf_source_destroy(tmp->data);
+      gconf_source_free(tmp->data);
       
       tmp = g_list_next(tmp);
     }
@@ -400,21 +386,31 @@ gconf_sources_query_value (GConfSources* sources,
                            const gchar** locales,
                            gboolean use_schema_default,
                            gboolean* value_is_default,
-                           GConfError** err)
+                           gboolean* value_is_writable,
+                           GError** err)
 {
   GList* tmp;
   gchar* schema_name = NULL;
-  GConfError* error = NULL;
+  GError* error = NULL;
   
   g_return_val_if_fail(sources != NULL, NULL);
   g_return_val_if_fail(key != NULL, NULL);
   g_return_val_if_fail((err == NULL) || (*err == NULL), NULL);
+
+  /* A value is writable if it is unset and a writable source exists,
+   * or if it's set and the setting is within or after a writable source.
+   * So basically if we see a writable source before we get the value,
+   * or get the value from a writable source, the value is writable.
+   */
   
   if (!gconf_key_check(key, err))
     return NULL;
 
   if (value_is_default)
     *value_is_default = FALSE;
+
+  if (value_is_writable)
+    *value_is_writable = FALSE;
   
   tmp = sources->sources;
 
@@ -431,6 +427,9 @@ gconf_sources_query_value (GConfSources* sources,
         schema_name_retloc = NULL;
       
       source = tmp->data;
+
+      if (source_is_writable (source, key, NULL)) /* ignore errors */
+        *value_is_writable = TRUE;
       
       val = gconf_source_query_value(source, key, locales,
                                      schema_name_retloc, &error);
@@ -443,7 +442,7 @@ gconf_sources_query_value (GConfSources* sources,
           if (err)
             *err = error;
           else
-            gconf_error_destroy(error);
+            g_error_free(error);
 
           error = NULL;
 
@@ -487,14 +486,14 @@ gconf_sources_query_value (GConfSources* sources,
       
       /* We do look for a schema describing the schema, just for funnies */
       val = gconf_sources_query_value(sources, schema_name, locales,
-                                      TRUE, NULL, &error);
+                                      TRUE, NULL, NULL, &error);
 
       if (error != NULL)
         {
           if (err)
             *err = error;
           else
-            gconf_error_destroy(error);
+            g_error_free(error);
 
           g_free(schema_name);
           return NULL;
@@ -511,10 +510,10 @@ gconf_sources_query_value (GConfSources* sources,
         }
       else if (val != NULL)
         {
-          GConfValue* retval = gconf_value_schema(val)->default_value;
+          GConfValue* retval = gconf_value_get_schema(val)->default_value;
           /* cheat, "unparent" the value to avoid a copy */
-          gconf_value_schema(val)->default_value = NULL;
-          gconf_value_destroy(val);
+          gconf_value_get_schema(val)->default_value = NULL;
+          gconf_value_free(val);
 
           g_free(schema_name);
           
@@ -536,7 +535,7 @@ void
 gconf_sources_set_value   (GConfSources* sources,
                            const gchar* key,
                            GConfValue* value,
-                           GConfError** err)
+                           GError** err)
 {
   GList* tmp;
 
@@ -564,7 +563,7 @@ gconf_sources_set_value   (GConfSources* sources,
 
       if (gconf_source_set_value(src, key, value, err))
         {
-          /* source was writeable */
+          /* source was writable */
           return;
         }
       else
@@ -579,7 +578,7 @@ gconf_sources_set_value   (GConfSources* sources,
           
           if (val != NULL)
             {
-              gconf_value_destroy(val);
+              gconf_value_free(val);
               gconf_set_error(err, GCONF_ERROR_OVERRIDDEN,
                               _("Value for `%s' set in a read-only source at the front of your configuration path."), key);
               return;
@@ -588,17 +587,24 @@ gconf_sources_set_value   (GConfSources* sources,
 
       tmp = g_list_next(tmp);
     }
+
+  /* If we arrived here, then there was nowhere to write a value */
+  g_set_error (err,
+               GCONF_ERROR,
+               GCONF_ERROR_NO_WRITABLE_DATABASE,
+               _("Unable to store a value at key '%s'"),
+               key);
 }
 
 void
 gconf_sources_unset_value   (GConfSources* sources,
                              const gchar* key,
                              const gchar* locale,
-                             GConfError** err)
+                             GError** err)
 {
   /* We unset in every layer we can write to... */
   GList* tmp;
-  GConfError* error = NULL;
+  GError* error = NULL;
   
   tmp = sources->sources;
 
@@ -608,7 +614,7 @@ gconf_sources_unset_value   (GConfSources* sources,
 
       if (gconf_source_unset_value(src, key, locale, &error))
         {
-          /* it was writeable */
+          /* it was writable */
 
           /* On error, set error and bail */
           if (error != NULL)
@@ -621,7 +627,7 @@ gconf_sources_unset_value   (GConfSources* sources,
                 }
               else
                 {
-                  gconf_error_destroy(error);
+                  g_error_free(error);
                   return;
                 }
             }
@@ -634,7 +640,7 @@ gconf_sources_unset_value   (GConfSources* sources,
 gboolean
 gconf_sources_dir_exists (GConfSources* sources,
                           const gchar* dir,
-                          GConfError** err)
+                          GError** err)
 {
   GList *tmp;
 
@@ -659,7 +665,7 @@ gconf_sources_dir_exists (GConfSources* sources,
 void          
 gconf_sources_remove_dir (GConfSources* sources,
                           const gchar* dir,
-                          GConfError** err)
+                          GError** err)
 {
   /* We remove in every layer we can write to... */
   GList* tmp;
@@ -672,7 +678,7 @@ gconf_sources_remove_dir (GConfSources* sources,
   while (tmp != NULL)
     {
       GConfSource* src = tmp->data;
-      GConfError* error = NULL;
+      GError* error = NULL;
       
       gconf_source_remove_dir(src, dir, &error);
 
@@ -687,7 +693,7 @@ gconf_sources_remove_dir (GConfSources* sources,
             }
           else
             {
-              gconf_error_destroy(error);
+              g_error_free(error);
               return;
             }
         }
@@ -700,7 +706,7 @@ void
 gconf_sources_set_schema        (GConfSources* sources,
                                  const gchar* key,
                                  const gchar* schema_key,
-                                 GConfError** err)
+                                 GError** err)
 {
   GList* tmp;
 
@@ -717,7 +723,7 @@ gconf_sources_set_schema        (GConfSources* sources,
       GConfSource* src = tmp->data;
 
       /* may set error, we just leave its setting */
-      /* returns TRUE if the source was writeable */
+      /* returns TRUE if the source was writable */
       if (gconf_source_set_schema(src, key, schema_key, err))
         return;
 
@@ -748,7 +754,7 @@ hash_destroy_entries_func(gpointer key, gpointer value, gpointer user_data)
 
   entry = value;
 
-  gconf_entry_destroy(entry);
+  gconf_entry_free(entry);
 }
 
 static void
@@ -770,43 +776,75 @@ hash_lookup_defaults_func(gpointer key, gpointer value, gpointer user_data)
   GConfSources *sources = dld->sources;
   const gchar** locales = dld->locales;
   
-  if (gconf_entry_value(entry) == NULL)
+  if (gconf_entry_get_value(entry) == NULL)
     {
-      if (gconf_entry_schema_name(entry) != NULL)
+      if (gconf_entry_get_schema_name(entry) != NULL)
         {
           GConfValue *val;
 
 
           val = gconf_sources_query_value(sources,
-                                          gconf_entry_schema_name(entry),
+                                          gconf_entry_get_schema_name(entry),
                                           locales,
                                           TRUE,
                                           NULL,
+                                          NULL,
                                           NULL);
 
           if (val != NULL &&
               val->type == GCONF_VALUE_SCHEMA)
             {
-              GConfValue* defval = gconf_value_schema(val)->default_value;
+              GConfValue* defval = gconf_value_get_schema(val)->default_value;
               /* cheat, "unparent" the value to avoid a copy */
-              gconf_value_schema(val)->default_value = NULL;
+              gconf_value_get_schema(val)->default_value = NULL;
 
               gconf_entry_set_value_nocopy(entry, defval);
               gconf_entry_set_is_default(entry, TRUE);
             }
 
           if (val)
-            gconf_value_destroy(val);
+            gconf_value_free(val);
         }
     }
 }
 
 
+static gboolean
+key_is_writable (GConfSources *sources,
+                 GConfSource  *value_in_src,
+                 const gchar *key,
+                 GError **err)
+{
+  GList *tmp;
+  
+  tmp = sources->sources;
+
+  while (tmp != NULL)
+    {
+      GConfSource* src;
+      
+      src = tmp->data;
+      
+      if (source_is_writable (src, key, NULL))
+        return TRUE;
+
+      if (src == value_in_src)
+        return FALSE; /* didn't find a writable source before value-containing
+                         source.
+                      */
+      
+      tmp = g_list_next (tmp);
+    }
+
+  /* This shouldn't be reached actually */
+  return FALSE;
+}
+
 GSList*       
 gconf_sources_all_entries   (GConfSources* sources,
                              const gchar* dir,
                              const gchar** locales,
-                             GConfError** err)
+                             GError** err)
 {
   GList* tmp;
   GHashTable* hash;
@@ -829,7 +867,7 @@ gconf_sources_all_entries   (GConfSources* sources,
       GConfSource* src;
       GSList* pairs;
       GSList* iter;
-      GConfError* error = NULL;
+      GError* error = NULL;
       
       src   = tmp->data;
       pairs = gconf_source_all_entries(src, dir, locales, &error);
@@ -850,18 +888,20 @@ gconf_sources_all_entries   (GConfSources* sources,
             }
           else
             {
-              gconf_error_destroy(error);
+              g_error_free(error);
               return NULL;
             }
         }
 
-      /* Iterate over the list of entries, stuffing them
-         in the hash if they're new */
+      /* Iterate over the list of entries, stuffing them in the hash
+         and setting their writability flag if they're new
+      */
       
       while (iter != NULL)
         {
           GConfEntry* pair = iter->data;
           GConfEntry* previous;
+          gchar *full;
           
           if (first_pass)
             previous = NULL; /* Can't possibly be there. */
@@ -870,20 +910,48 @@ gconf_sources_all_entries   (GConfSources* sources,
           
           if (previous != NULL)
             {
-              if (gconf_entry_value(previous) != NULL)
+              if (gconf_entry_get_value(previous) != NULL)
                 /* Discard this latest one */
                 ;
               else
-                /* Save the new value, previously we had an entry but no value */
-                gconf_entry_set_value_nocopy(previous,
-                                             gconf_entry_steal_value(pair));
+                {
+                  /* Save the new value, previously we had an entry but no value */
+                  gconf_entry_set_value_nocopy(previous,
+                                               gconf_entry_steal_value(pair));
+
+                  /* As an efficiency hack, remember that
+                   * entry->key is relative not absolute on the
+                   * gconfd side
+                   */
+                  full = gconf_concat_dir_and_key (dir, previous->key);
+                  
+                  previous->is_writable = key_is_writable (sources,
+                                                           src,
+                                                           full,
+                                                           NULL);
+
+                  g_free (full);
+                }
               
-              gconf_entry_destroy(pair);
+              gconf_entry_free(pair);
             }
           else
             {
               /* Save */
               g_hash_table_insert(hash, pair->key, pair);
+              
+              /* As an efficiency hack, remember that
+               * entry->key is relative not absolute on the
+               * gconfd side
+               */
+              full = gconf_concat_dir_and_key (dir, pair->key);
+              
+              previous->is_writable = key_is_writable (sources,
+                                                       src,
+                                                       full,
+                                                       NULL);
+              
+              g_free (full);
             }
 
           iter = g_slist_next(iter);
@@ -904,14 +972,14 @@ gconf_sources_all_entries   (GConfSources* sources,
   g_hash_table_foreach(hash, hash_listify_func, &flattened);
 
   g_hash_table_destroy(hash);
-
+  
   return flattened;
 }
 
 GSList*       
 gconf_sources_all_dirs   (GConfSources* sources,
                           const gchar* dir,
-                          GConfError** err)
+                          GError** err)
 {
   GList* tmp = NULL;
   GHashTable* hash = NULL;
@@ -931,7 +999,7 @@ gconf_sources_all_dirs   (GConfSources* sources,
 
   if (sources->sources->next == NULL)
     {
-      return gconf_source_all_dirs(sources->sources->data, dir, err);
+      return gconf_source_all_dirs (sources->sources->data, dir, err);
     }
 
   /* 2 or more sources */
@@ -946,7 +1014,7 @@ gconf_sources_all_dirs   (GConfSources* sources,
       GConfSource* src;
       GSList* subdirs;
       GSList* iter;
-      GConfError* error = NULL;
+      GError* error = NULL;
       
       src     = tmp->data;
       subdirs = gconf_source_all_dirs(src, dir, &error);
@@ -955,9 +1023,9 @@ gconf_sources_all_dirs   (GConfSources* sources,
       /* On error, set error and bail */
       if (error != NULL)
         {
-          g_hash_table_foreach(hash, hash_destroy_pointers_func, NULL);
+          g_hash_table_foreach (hash, hash_destroy_pointers_func, NULL);
           
-          g_hash_table_destroy(hash);
+          g_hash_table_destroy (hash);
           
           if (err)
             {
@@ -967,7 +1035,7 @@ gconf_sources_all_dirs   (GConfSources* sources,
             }
           else
             {
-              gconf_error_destroy(error);
+              g_error_free(error);
               return NULL;
             }
         }
@@ -1014,18 +1082,18 @@ gconf_sources_all_dirs   (GConfSources* sources,
 }
 
 gboolean
-gconf_sources_sync_all    (GConfSources* sources, GConfError** err)
+gconf_sources_sync_all    (GConfSources* sources, GError** err)
 {
   GList* tmp;
   gboolean failed = FALSE;
-  GConfError* all_errors = NULL;
+  GError* all_errors = NULL;
   
   tmp = sources->sources;
 
   while (tmp != NULL)
     {
       GConfSource* src = tmp->data;
-      GConfError* error = NULL;
+      GError* error = NULL;
       
       if (!gconf_source_sync_all(src, &error))
         {
@@ -1039,7 +1107,7 @@ gconf_sources_sync_all    (GConfSources* sources, GConfError** err)
           if (err)
             all_errors = gconf_compose_errors(all_errors, error);
 
-          gconf_error_destroy(error);
+          g_error_free(error);
         }
           
       tmp = g_list_next(tmp);
@@ -1057,7 +1125,7 @@ gconf_sources_sync_all    (GConfSources* sources, GConfError** err)
 GConfMetaInfo*
 gconf_sources_query_metainfo (GConfSources* sources,
                               const gchar* key,
-                              GConfError** err)
+                              GError** err)
 {
   GList* tmp;
   GConfMetaInfo* mi = NULL;
@@ -1067,7 +1135,7 @@ gconf_sources_query_metainfo (GConfSources* sources,
   while (tmp != NULL)
     {
       GConfSource* src = tmp->data;
-      GConfError* error = NULL;
+      GError* error = NULL;
       GConfMetaInfo* this_mi;
 
       this_mi = gconf_source_query_metainfo(src, key, &error);
@@ -1076,8 +1144,8 @@ gconf_sources_query_metainfo (GConfSources* sources,
       if (error != NULL)
         {
           g_assert(this_mi == NULL);
-          gconf_log(GCL_ERR, _("Error finding metainfo: %s"), error->str);
-          gconf_error_destroy(error);
+          gconf_log(GCL_ERR, _("Error finding metainfo: %s"), error->message);
+          g_error_free(error);
           error = NULL;
         }
 
@@ -1089,18 +1157,18 @@ gconf_sources_query_metainfo (GConfSources* sources,
             {
               /* Fill in any missing fields of "mi" found in "this_mi",
                  and pick the most recent mod time */
-              if (gconf_meta_info_schema(mi) == NULL &&
-                  gconf_meta_info_schema(this_mi) != NULL)
+              if (gconf_meta_info_get_schema(mi) == NULL &&
+                  gconf_meta_info_get_schema(this_mi) != NULL)
                 {
                   gconf_meta_info_set_schema(mi,
-                                             gconf_meta_info_schema(mi));
+                                             gconf_meta_info_get_schema(mi));
                 }
 
-              if (gconf_meta_info_mod_user(mi) == NULL &&
-                  gconf_meta_info_mod_user(this_mi) != NULL)
+              if (gconf_meta_info_get_mod_user(mi) == NULL &&
+                  gconf_meta_info_get_mod_user(this_mi) != NULL)
                 {
                   gconf_meta_info_set_mod_user(mi,
-                                               gconf_meta_info_mod_user(this_mi));
+                                               gconf_meta_info_get_mod_user(this_mi));
                 }
               
               if (gconf_meta_info_mod_time(mi) < gconf_meta_info_mod_time(this_mi))
@@ -1109,7 +1177,7 @@ gconf_sources_query_metainfo (GConfSources* sources,
                                                gconf_meta_info_mod_time(this_mi));
                 }
 
-              gconf_meta_info_destroy(this_mi);
+              gconf_meta_info_free(this_mi);
             }
         }
       
@@ -1123,13 +1191,17 @@ GConfValue*
 gconf_sources_query_default_value(GConfSources* sources,
                                   const gchar* key,
                                   const gchar** locales,
-                                  GConfError** err)
+                                  gboolean* is_writable,
+                                  GError** err)
 {
-  GConfError* error = NULL;
+  GError* error = NULL;
   GConfValue* val;
   GConfMetaInfo* mi;
   
   g_return_val_if_fail(err == NULL || *err == NULL, NULL);
+
+  if (is_writable)
+    *is_writable = key_is_writable (sources, NULL, key, NULL);
   
   mi = gconf_sources_query_metainfo(sources, key,
                                     &error);
@@ -1141,22 +1213,22 @@ gconf_sources_query_default_value(GConfSources* sources,
             *err = error;
           else
             {
-              gconf_log(GCL_ERR, _("Error getting metainfo: %s"), error->str);
-              gconf_error_destroy(error);
+              gconf_log(GCL_ERR, _("Error getting metainfo: %s"), error->message);
+              g_error_free(error);
             }
         }
       return NULL;
     }
 
-  if (gconf_meta_info_schema(mi) == NULL)
+  if (gconf_meta_info_get_schema(mi) == NULL)
     {
-      gconf_meta_info_destroy(mi);
+      gconf_meta_info_free(mi);
       return NULL;
     }
       
   val = gconf_sources_query_value(sources,
-                                  gconf_meta_info_schema(mi), locales,
-                                  TRUE, NULL, &error);
+                                  gconf_meta_info_get_schema(mi), locales,
+                                  TRUE, NULL, NULL, &error);
   
   if (val != NULL)
     {
@@ -1166,20 +1238,20 @@ gconf_sources_query_default_value(GConfSources* sources,
         {
           gconf_log(GCL_WARNING,
                     _("Key `%s' listed as schema for key `%s' actually stores type `%s'"),
-                    gconf_meta_info_schema(mi),
+                    gconf_meta_info_get_schema(mi),
                     key,
                     gconf_value_type_to_string(val->type));
 
-          gconf_meta_info_destroy(mi);
+          gconf_meta_info_free(mi);
           return NULL;
         }
 
-      gconf_meta_info_destroy(mi);
+      gconf_meta_info_free(mi);
 
-      schema = gconf_value_schema(val);
+      schema = gconf_value_get_schema(val);
       val->d.schema_data = NULL; /* cheat, steal schema from the GConfValue */
       
-      gconf_value_destroy(val); /* schema not destroyed due to our cheat */
+      gconf_value_free(val); /* schema not destroyed due to our cheat */
       
       if (schema != NULL)
         {
@@ -1188,7 +1260,7 @@ gconf_sources_query_default_value(GConfSources* sources,
           retval = schema->default_value;
           schema->default_value = NULL;
 
-          gconf_schema_destroy(schema);
+          gconf_schema_free(schema);
           
           return retval;
         }
@@ -1203,13 +1275,13 @@ gconf_sources_query_default_value(GConfSources* sources,
           else
             {
               gconf_log(GCL_ERR, _("Error getting value for `%s': %s"),
-                        gconf_meta_info_schema(mi),
-                        error->str);
-              gconf_error_destroy(error);
+                        gconf_meta_info_get_schema(mi),
+                        error->message);
+              g_error_free(error);
             }
         }
       
-      gconf_meta_info_destroy(mi);
+      gconf_meta_info_free(mi);
       
       return NULL;
     }
