@@ -27,20 +27,6 @@
 #include <stdlib.h>
 #include <errno.h>
 
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
 static int set_mode = FALSE;
 static int get_mode = FALSE;
 static int unset_mode = FALSE;
@@ -326,7 +312,7 @@ main (int argc, char** argv)
   GConfEngine* conf;
   poptContext ctx;
   gint nextopt;
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   ctx = poptGetContext("gconftool", argc, argv, options, 0);
 
@@ -474,8 +460,8 @@ main (int argc, char** argv)
   
   if (!gconf_init(argc, argv, &err))
     {
-      fprintf(stderr, _("Failed to init GConf: %s\n"), err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, _("Failed to init GConf: %s\n"), err->message);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
@@ -536,8 +522,8 @@ main (int argc, char** argv)
   if (conf == NULL)
     {
       g_assert(err != NULL);
-      fprintf(stderr, _("Failed to access configuration source(s): %s\n"), err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, _("Failed to access configuration source(s): %s\n"), err->message);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
@@ -697,8 +683,8 @@ main (int argc, char** argv)
   if (err != NULL)
     {
       fprintf(stderr, _("Shutdown error: %s\n"),
-              err->str);
-      gconf_error_destroy(err);
+              err->message);
+      g_error_free(err);
       err = NULL;
     }
 
@@ -718,13 +704,13 @@ recurse_subdir_list(GConfEngine* conf, GSList* subdirs, const gchar* parent, gui
   while (tmp != NULL)
     {
       gchar* s = tmp->data;
-      gchar* full = gconf_concat_key_and_dir(parent, s);
+      gchar* full = gconf_concat_dir_and_key(parent, s);
       
       printf("%s%s:\n", whitespace, s);
       
       list_pairs_in_dir(conf, full, depth);
 
-      recurse_subdir_list(conf, gconf_all_dirs(conf, full, NULL), full, depth+1);
+      recurse_subdir_list(conf, gconf_engine_all_dirs(conf, full, NULL), full, depth+1);
 
       g_free(s);
       g_free(full);
@@ -749,7 +735,7 @@ do_recursive_list(GConfEngine* conf, const gchar** args)
     {
       GSList* subdirs;
 
-      subdirs = gconf_all_dirs(conf, *args, NULL);
+      subdirs = gconf_engine_all_dirs(conf, *args, NULL);
 
       list_pairs_in_dir(conf, *args, 0);
           
@@ -767,17 +753,17 @@ list_pairs_in_dir(GConfEngine* conf, const gchar* dir, guint depth)
   GSList* pairs;
   GSList* tmp;
   gchar* whitespace;
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   whitespace = g_strnfill(depth, ' ');
 
-  pairs = gconf_all_entries(conf, dir, &err);
+  pairs = gconf_engine_all_entries(conf, dir, &err);
           
   if (err != NULL)
     {
       fprintf(stderr, _("Failure listing pairs in `%s': %s"),
-              dir, err->str);
-      gconf_error_destroy(err);
+              dir, err->message);
+      g_error_free(err);
       err = NULL;
     }
 
@@ -795,11 +781,13 @@ list_pairs_in_dir(GConfEngine* conf, const gchar* dir, guint depth)
           else
                   s = g_strdup(_("(no value set)"));
           
-          printf(" %s%s = %s\n", whitespace, pair->key, s);
+          printf(" %s%s = %s\n", whitespace,
+                 gconf_key_key (gconf_entry_get_key (pair)),
+                 s);
 
           g_free(s);
                   
-          gconf_entry_destroy(pair);
+          gconf_entry_free(pair);
 
           tmp = g_slist_next(tmp);
         }
@@ -824,15 +812,15 @@ do_all_pairs(GConfEngine* conf, const gchar** args)
 static gboolean
 do_dir_exists(GConfEngine* conf, const gchar* dir)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   gboolean exists = FALSE;
   
-  exists = gconf_dir_exists(conf, dir_exists, &err);
+  exists = gconf_engine_dir_exists(conf, dir_exists, &err);
   
   if (err != NULL)
     {
-      fprintf(stderr, "%s\n", err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, "%s\n", err->message);
+      g_error_free(err);
       err = NULL;
     }
   
@@ -842,13 +830,13 @@ do_dir_exists(GConfEngine* conf, const gchar* dir)
 static void
 do_spawn_daemon(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
 
   if (!gconf_spawn_daemon(&err))
     {
       fprintf(stderr, _("Failed to spawn the config server (gconfd): %s\n"), 
-              err->str);
-      gconf_error_destroy(err);
+              err->message);
+      g_error_free(err);
       err = NULL;
     }
 }
@@ -856,7 +844,7 @@ do_spawn_daemon(GConfEngine* conf)
 static int
 do_get(GConfEngine* conf, const gchar** args)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
 
   if (args == NULL)
     {
@@ -871,7 +859,7 @@ do_get(GConfEngine* conf, const gchar** args)
 
       err = NULL;
 
-      value = gconf_get(conf, *args, &err);
+      value = gconf_engine_get (conf, *args, &err);
          
       if (value != NULL)
         {
@@ -885,14 +873,14 @@ do_get(GConfEngine* conf, const gchar** args)
             }
           else
             {
-              GConfSchema* sc = gconf_value_schema(value);
-              GConfValueType stype = gconf_schema_type(sc);
-              GConfValueType slist_type = gconf_schema_list_type(sc);
-              GConfValueType scar_type = gconf_schema_car_type(sc);
-              GConfValueType scdr_type = gconf_schema_cdr_type(sc);
-              const gchar* long_desc = gconf_schema_long_desc(sc);
-              const gchar* short_desc = gconf_schema_short_desc(sc);
-              const gchar* owner = gconf_schema_owner(sc);
+              GConfSchema* sc = gconf_value_get_schema(value);
+              GConfValueType stype = gconf_schema_get_type(sc);
+              GConfValueType slist_type = gconf_schema_get_list_type(sc);
+              GConfValueType scar_type = gconf_schema_get_car_type(sc);
+              GConfValueType scdr_type = gconf_schema_get_cdr_type(sc);
+              const gchar* long_desc = gconf_schema_get_long_desc(sc);
+              const gchar* short_desc = gconf_schema_get_short_desc(sc);
+              const gchar* owner = gconf_schema_get_owner(sc);
 
               printf(_("Type: %s\n"), gconf_value_type_to_string(stype));
               printf(_("List Type: %s\n"), gconf_value_type_to_string(slist_type));
@@ -903,7 +891,7 @@ do_get(GConfEngine* conf, const gchar** args)
               printf(_("Long Desc: %s\n"), long_desc ? long_desc : _("Unset"));
             }
 
-          gconf_value_destroy(value);
+          gconf_value_free(value);
         }
       else
         {
@@ -914,8 +902,8 @@ do_get(GConfEngine* conf, const gchar** args)
           else
             {
               fprintf(stderr, _("Failed to get value for `%s': %s\n"),
-                      *args, err->str);
-              gconf_error_destroy(err);
+                      *args, err->message);
+              g_error_free(err);
               err = NULL;
             }
         }
@@ -976,7 +964,7 @@ read_value_type(const char *string)
 static int
 do_set(GConfEngine* conf, const gchar** args)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (args == NULL)
     {
@@ -1068,38 +1056,38 @@ do_set(GConfEngine* conf, const gchar** args)
       if (gval == NULL)
         {
           fprintf(stderr, _("Error: %s\n"),
-                  err->str);
-          gconf_error_destroy(err);
+                  err->message);
+          g_error_free(err);
           err = NULL;
           return 1;
         }
 
       err = NULL;
           
-      gconf_set(conf, key, gval, &err);
+      gconf_engine_set (conf, key, gval, &err);
 
       if (err != NULL)
         {
           fprintf(stderr, _("Error setting value: %s"),
-                  err->str);
-          gconf_error_destroy(err);
+                  err->message);
+          g_error_free(err);
           err = NULL;
           return 1;
         }
 
-      gconf_value_destroy(gval);
+      gconf_value_free(gval);
 
       ++args;
     }
 
   err = NULL;
 
-  gconf_suggest_sync(conf, &err);
+  gconf_engine_suggest_sync(conf, &err);
 
   if (err != NULL)
     {
       fprintf(stderr, _("Error syncing: %s"),
-              err->str);
+              err->message);
       return 1;
     }
 
@@ -1112,7 +1100,7 @@ do_set_schema(GConfEngine* conf, const gchar** args)
   GConfSchema* sc;
   GConfValue* val;
   const gchar* key;
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if ((args == NULL) || (args[1] != NULL))
     {
@@ -1209,27 +1197,27 @@ do_set_schema(GConfEngine* conf, const gchar** args)
 
   err = NULL;
       
-  gconf_set(conf, key, val, &err);
+  gconf_engine_set (conf, key, val, &err);
       
   if (err != NULL)
     {
       fprintf(stderr, _("Error setting value: %s"),
-              err->str);
-      gconf_error_destroy(err);
+              err->message);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
       
-  gconf_value_destroy(val);
+  gconf_value_free(val);
 
   err = NULL;
-  gconf_suggest_sync(conf, &err);
+  gconf_engine_suggest_sync(conf, &err);
       
   if (err != NULL)
     {
       fprintf(stderr, _("Error syncing: %s"),
-              err->str);
-      gconf_error_destroy(err);
+              err->message);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
@@ -1252,7 +1240,7 @@ do_all_entries(GConfEngine* conf, const gchar** args)
 static int
 do_unset(GConfEngine* conf, const gchar** args)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (args == NULL)
     {
@@ -1263,13 +1251,13 @@ do_unset(GConfEngine* conf, const gchar** args)
   while (*args)
     {
       err = NULL;
-      gconf_unset(conf, *args, &err);
+      gconf_engine_unset(conf, *args, &err);
 
       if (err != NULL)
         {
           fprintf(stderr, _("Error unsetting `%s': %s\n"),
-                  *args, err->str);
-          gconf_error_destroy(err);
+                  *args, err->message);
+          g_error_free(err);
           err = NULL;
         }
 
@@ -1277,7 +1265,7 @@ do_unset(GConfEngine* conf, const gchar** args)
     }
 
   err = NULL;
-  gconf_suggest_sync(conf, NULL); /* ignore errors */
+  gconf_engine_suggest_sync(conf, NULL); /* ignore errors */
 
   return 0;
 }
@@ -1286,7 +1274,7 @@ do_unset(GConfEngine* conf, const gchar** args)
 static int
 do_all_subdirs(GConfEngine* conf, const gchar** args)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (args == NULL)
     {
@@ -1301,7 +1289,7 @@ do_all_subdirs(GConfEngine* conf, const gchar** args)
 
       err = NULL;
 
-      subdirs = gconf_all_dirs(conf, *args, &err);
+      subdirs = gconf_engine_all_dirs(conf, *args, &err);
           
       if (subdirs != NULL)
         {
@@ -1325,8 +1313,8 @@ do_all_subdirs(GConfEngine* conf, const gchar** args)
           if (err != NULL)
             {
               fprintf(stderr, _("Error listing dirs: %s\n"),
-                      err->str);
-              gconf_error_destroy(err);
+                      err->message);
+              g_error_free(err);
               err = NULL;
             }
         }
@@ -1372,7 +1360,7 @@ fill_default_from_string(SchemaInfo* info, const gchar* default_value,
 
     case GCONF_VALUE_LIST:
       {
-        GConfError* error = NULL;
+        GError* error = NULL;
         if (info->list_type == GCONF_VALUE_INVALID)
 	  {
             fprintf(stderr, _("WARNING: invalid or missing list_type for schema (%s)\n"),
@@ -1388,7 +1376,7 @@ fill_default_from_string(SchemaInfo* info, const gchar* default_value,
 
             fprintf(stderr, _("WARNING: Failed to parse default value `%s' for schema (%s)\n"), default_value, info->key);
 
-            gconf_error_destroy(error);
+            g_error_free(error);
             error = NULL;
           }
         else
@@ -1400,7 +1388,7 @@ fill_default_from_string(SchemaInfo* info, const gchar* default_value,
 
     case GCONF_VALUE_PAIR:
       {
-        GConfError* error = NULL;
+        GError* error = NULL;
         if (info->car_type == GCONF_VALUE_INVALID ||
 	    info->cdr_type == GCONF_VALUE_INVALID)
 	  {
@@ -1418,7 +1406,7 @@ fill_default_from_string(SchemaInfo* info, const gchar* default_value,
 
             fprintf(stderr, _("WARNING: Failed to parse default value `%s' for schema (%s)\n"), default_value, info->key);
 
-            gconf_error_destroy(error);
+            g_error_free(error);
             error = NULL;
           }
         else
@@ -1437,7 +1425,7 @@ fill_default_from_string(SchemaInfo* info, const gchar* default_value,
     case GCONF_VALUE_BOOL:
     case GCONF_VALUE_FLOAT:
       {
-        GConfError* error = NULL;
+        GError* error = NULL;
         *retloc = gconf_value_new_from_string(info->type,
                                               default_value,
                                               &error);
@@ -1447,7 +1435,7 @@ fill_default_from_string(SchemaInfo* info, const gchar* default_value,
 
             fprintf(stderr, _("WARNING: Failed to parse default value `%s' for schema (%s)\n"), default_value, info->key);
 
-            gconf_error_destroy(error);
+            g_error_free(error);
             error = NULL;
           }
         else
@@ -1734,7 +1722,7 @@ process_locale_info(xmlNodePtr node, SchemaInfo* info)
     }
 
   g_hash_table_insert(info->hash,
-                      (gchar*)gconf_schema_locale(schema), /* cheat to save copying this string */
+                      (gchar*)gconf_schema_get_locale(schema), /* cheat to save copying this string */
                       schema);
 
   return 0;
@@ -1745,28 +1733,28 @@ hash_foreach(gpointer key, gpointer value, gpointer user_data)
 {
   SchemaInfo* info;
   GConfSchema* schema;
-  GConfError* error = NULL;
+  GError* error = NULL;
   
   info = user_data;
   schema = value;
   
-  if (!gconf_set_schema(info->conf, info->key, schema, &error))
+  if (!gconf_engine_set_schema(info->conf, info->key, schema, &error))
     {
       g_assert(error != NULL);
 
       fprintf(stderr, _("WARNING: failed to install schema `%s' locale `%s': %s\n"),
-              info->key, gconf_schema_locale(schema), error->str);
-      gconf_error_destroy(error);
+              info->key, gconf_schema_get_locale(schema), error->message);
+      g_error_free(error);
       error = NULL;
     }
   else
     {
       g_assert(error == NULL);
       printf(_("Installed schema `%s' for locale `%s'\n"),
-             info->key, gconf_schema_locale(schema));
+             info->key, gconf_schema_get_locale(schema));
     }
       
-  gconf_schema_destroy(schema);
+  gconf_schema_free(schema);
 }
 
 
@@ -1774,19 +1762,19 @@ static int
 process_key_list(GConfEngine* conf, const gchar* schema_name, GSList* keylist)
 {
   GSList* tmp;
-  GConfError* error = NULL;
+  GError* error = NULL;
 
   tmp = keylist;
 
   while (tmp != NULL)
     {
-      if (!gconf_associate_schema(conf, tmp->data, schema_name,  &error))
+      if (!gconf_engine_associate_schema(conf, tmp->data, schema_name,  &error))
         {
           g_assert(error != NULL);
           
           fprintf(stderr, _("WARNING: failed to associate schema `%s' with key `%s': %s\n"),
-                  schema_name, (gchar*)tmp->data, error->str);
-          gconf_error_destroy(error);
+                  schema_name, (gchar*)tmp->data, error->message);
+          g_error_free(error);
           error = NULL;
         }
       else
@@ -1826,7 +1814,7 @@ process_schema(GConfEngine* conf, xmlNodePtr node)
       g_free(info.owner);
 
       if (info.global_default)
-        gconf_value_destroy(info.global_default);
+        gconf_value_free(info.global_default);
 
       return 1;
     }
@@ -1883,7 +1871,7 @@ process_schema(GConfEngine* conf, xmlNodePtr node)
   g_free(info.key);
   g_free(info.owner);
   if (info.global_default)
-    gconf_value_destroy(info.global_default);
+    gconf_value_free(info.global_default);
   
   return 0;
 }
@@ -1914,7 +1902,7 @@ do_load_schema_file(GConfEngine* conf, const gchar* file)
 {
   xmlDocPtr doc;
   xmlNodePtr iter;
-  GConfError * err = NULL;
+  GError * err = NULL;
   
   errno = 0;
   doc = xmlParseFile(file);
@@ -1975,13 +1963,13 @@ do_load_schema_file(GConfEngine* conf, const gchar* file)
       iter = iter->next;
     }
 
-  gconf_suggest_sync(conf, &err);
+  gconf_engine_suggest_sync(conf, &err);
 
   if (err != NULL)
     {
       fprintf(stderr, _("Error syncing config data: %s"),
-              err->str);
-      gconf_error_destroy(err);
+              err->message);
+      g_error_free(err);
       return 1;
     }
   
@@ -1991,7 +1979,7 @@ do_load_schema_file(GConfEngine* conf, const gchar* file)
 static int
 do_makefile_install(GConfEngine* conf, const gchar** args)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (args == NULL)
     {
@@ -2007,13 +1995,13 @@ do_makefile_install(GConfEngine* conf, const gchar** args)
       ++args;
     }
 
-  gconf_suggest_sync(conf, &err);
+  gconf_engine_suggest_sync(conf, &err);
 
   if (err != NULL)
     {
       fprintf(stderr, _("Error syncing config data: %s"),
-              err->str);
-      gconf_error_destroy(err);
+              err->message);
+      g_error_free(err);
       return 1;
     }
   
@@ -2026,15 +2014,15 @@ typedef enum {
 } BreakagePhase;
 
 static gboolean
-check_err(GConfError** err)
+check_err(GError** err)
 {
   printf(".");
   
   if (*err != NULL)
     {
       fprintf(stderr, _("\n%s\n"),
-              (*err)->str);
-      gconf_error_destroy(*err);
+              (*err)->message);
+      g_error_free(*err);
       *err = NULL;
       return TRUE;
     }
@@ -2045,16 +2033,16 @@ check_err(GConfError** err)
 static gboolean
 key_breakage(GConfEngine* conf, const gchar* key, BreakagePhase phase)
 {
-  GConfError* error = NULL;
+  GError* error = NULL;
   
   if (phase == BreakageCleanup)
     {
-      gconf_unset(conf, key, &error);
+      gconf_engine_unset(conf, key, &error);
       if (error != NULL)
         {
           fprintf(stderr, _("Failed to unset breakage key %s: %s\n"),
-                  key, error->str);
-          gconf_error_destroy(error);
+                  key, error->message);
+          g_error_free(error);
           return FALSE;
         }
     }
@@ -2069,75 +2057,75 @@ key_breakage(GConfEngine* conf, const gchar* key, BreakagePhase phase)
       
       printf("  +");
       
-      gconf_set_string(conf, key, "", &error);
+      gconf_engine_set_string(conf, key, "", &error);
       if (check_err(&error))
         return FALSE;
       
-      gconf_set_string(conf, key, "blah blah blah 93475028934670 @%^%$&%$&^%", &error);
+      gconf_engine_set_string(conf, key, "blah blah blah 93475028934670 @%^%$&%$&^%", &error);
       if (check_err(&error))
         return FALSE;
       
-      gconf_set_bool(conf, key, TRUE, &error);
+      gconf_engine_set_bool(conf, key, TRUE, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_bool(conf, key, FALSE, &error);
+      gconf_engine_set_bool(conf, key, FALSE, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_float(conf, key, 100.0, &error);
+      gconf_engine_set_float(conf, key, 100.0, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_float(conf, key, -100.0, &error);
+      gconf_engine_set_float(conf, key, -100.0, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_float(conf, key, 0.0, &error);
+      gconf_engine_set_float(conf, key, 0.0, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_int(conf, key, 0, &error);
+      gconf_engine_set_int(conf, key, 0, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_int(conf, key, 5384750, &error);
+      gconf_engine_set_int(conf, key, 5384750, &error);
       if (check_err(&error))
         return FALSE;
       
-      gconf_set_int(conf, key, -11, &error);
+      gconf_engine_set_int(conf, key, -11, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_list(conf, key, GCONF_VALUE_BOOL, list, &error);
+      gconf_engine_set_list(conf, key, GCONF_VALUE_BOOL, list, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_pair(conf, key, GCONF_VALUE_INT, GCONF_VALUE_BOOL,
+      gconf_engine_set_pair(conf, key, GCONF_VALUE_INT, GCONF_VALUE_BOOL,
                      &an_int, &a_bool, &error);
       if (check_err(&error))
         return FALSE;
 
-      gconf_set_pair(conf, key, GCONF_VALUE_FLOAT, GCONF_VALUE_STRING,
+      gconf_engine_set_pair(conf, key, GCONF_VALUE_FLOAT, GCONF_VALUE_STRING,
                      &a_float, &a_string, &error);
       if (check_err(&error))
         return FALSE;
 
       /* empty pair */
       val = gconf_value_new(GCONF_VALUE_PAIR);
-      gconf_set(conf, key, val, &error);
-      gconf_value_destroy(val);
+      gconf_engine_set (conf, key, val, &error);
+      gconf_value_free(val);
       if (check_err(&error))
         return FALSE;
 
       list = NULL;
-      gconf_set_list(conf, key, GCONF_VALUE_STRING, list, &error);
+      gconf_engine_set_list(conf, key, GCONF_VALUE_STRING, list, &error);
       if (check_err(&error))
         return FALSE;
-      gconf_set_list(conf, key, GCONF_VALUE_INT, list, &error);
+      gconf_engine_set_list(conf, key, GCONF_VALUE_INT, list, &error);
       if (check_err(&error))
         return FALSE;
-      gconf_set_list(conf, key, GCONF_VALUE_BOOL, list, &error);
+      gconf_engine_set_list(conf, key, GCONF_VALUE_BOOL, list, &error);
       if (check_err(&error))
         return FALSE;
 
@@ -2146,7 +2134,7 @@ key_breakage(GConfEngine* conf, const gchar* key, BreakagePhase phase)
       list = g_slist_prepend(list, GINT_TO_POINTER(-93));
       list = g_slist_prepend(list, GINT_TO_POINTER(1000000));
       list = g_slist_prepend(list, GINT_TO_POINTER(32));
-      gconf_set_list(conf, key, GCONF_VALUE_INT, list, &error);
+      gconf_engine_set_list(conf, key, GCONF_VALUE_INT, list, &error);
       if (check_err(&error))
         return FALSE;
 
@@ -2158,7 +2146,7 @@ key_breakage(GConfEngine* conf, const gchar* key, BreakagePhase phase)
       list = g_slist_prepend(list, "");
       list = g_slist_prepend(list, "\n\t\r\n     \n");
       list = g_slist_prepend(list, "woo fooo s^%*^%&@^$@%&@%$");
-      gconf_set_list(conf, key, GCONF_VALUE_STRING, list, &error);
+      gconf_engine_set_list(conf, key, GCONF_VALUE_STRING, list, &error);
       if (check_err(&error))
         return FALSE;
 
@@ -2216,7 +2204,7 @@ do_break_directory(GConfEngine* conf, const gchar** args)
       while (i < 10)
         {
           keys[i] = gconf_unique_key();
-          full_keys[i] = gconf_concat_key_and_dir(*args, keys[i]);
+          full_keys[i] = gconf_concat_dir_and_key(*args, keys[i]);
 
           ++i;
         }
