@@ -142,7 +142,7 @@ static const guint n_floats = sizeof(floats)/sizeof(floats[0]);
 static void
 check_unset(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   GConfChangeSet* cs;
 
@@ -158,12 +158,12 @@ check_unset(GConfEngine* conf)
     }
 
   
-  gconf_commit_change_set(conf, cs, TRUE, &err);
+  gconf_engine_commit_change_set(conf, cs, TRUE, &err);
   
   if (err != NULL)
     {
-      fprintf(stderr, "unset commit failed: %s\n", err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, "unset commit failed: %s\n", err->message);
+      g_error_free(err);
       err = NULL;
       exit(1);
     }
@@ -176,7 +176,7 @@ check_unset(GConfEngine* conf)
       GConfValue* val;
       gchar* valstr;
       
-      val = gconf_get(conf, *keyp, &err);
+      val = gconf_engine_get (conf, *keyp, &err);
       
       if (val)
         valstr = gconf_value_to_string(val);
@@ -194,7 +194,7 @@ check_unset(GConfEngine* conf)
 static void
 check_string_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   const gchar** valp = NULL;
   GConfChangeSet* cs;
@@ -212,12 +212,12 @@ check_string_storage(GConfEngine* conf)
       ++keyp;
     }
 
-  gconf_commit_change_set(conf, cs, TRUE, &err);
+  gconf_engine_commit_change_set(conf, cs, TRUE, &err);
   
   if (err != NULL)
     {
-      fprintf(stderr, "set commit failed: %s\n", err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, "set commit failed: %s\n", err->message);
+      g_error_free(err);
       err = NULL;
       exit(1);
     }
@@ -231,14 +231,14 @@ check_string_storage(GConfEngine* conf)
     {
       gchar* gotten;
       
-      gotten = gconf_get_string(conf, *keyp, &err);
+      gotten = gconf_engine_get_string(conf, *keyp, &err);
       
       if (err != NULL)
         {
           check(gotten == NULL, "string was returned though there was an error");
           fprintf(stderr, "Failed to get key `%s': %s\n",
-                  *keyp, err->str);
-          gconf_error_destroy(err);
+                  *keyp, err->message);
+          g_error_free(err);
           err = NULL;
           exit(1);
         }
@@ -261,12 +261,12 @@ int
 main (int argc, char** argv)
 {
   GConfEngine* conf;
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (!gconf_init(argc, argv, &err))
     {
-      fprintf(stderr, "Failed to init GConf: %s\n", err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, "Failed to init GConf: %s\n", err->message);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
