@@ -149,19 +149,19 @@ static const guint n_floats = sizeof(floats)/sizeof(floats[0]);
 static void
 check_unset(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
 
   keyp = keys;
 
   while (*keyp)
     {
-      gconf_unset(conf, *keyp, &err);
+      gconf_engine_unset(conf, *keyp, &err);
 
       if (err != NULL)
         {
-          fprintf(stderr, "unset of `%s' failed: %s\n", *keyp, err->str);
-          gconf_error_destroy(err);
+          fprintf(stderr, "unset of `%s' failed: %s\n", *keyp, err->message);
+          g_error_free(err);
           err = NULL;
         }
       else
@@ -171,7 +171,7 @@ check_unset(GConfEngine* conf)
 
           sync_and_clear(conf);
           
-          val = gconf_get(conf, *keyp, &err);
+          val = gconf_engine_get (conf, *keyp, &err);
 
 
           if (val)
@@ -191,7 +191,7 @@ check_unset(GConfEngine* conf)
 static void
 check_string_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   const gchar** valp = NULL;
 
@@ -207,25 +207,25 @@ check_string_storage(GConfEngine* conf)
         {
           gchar* gotten;
           
-          if (!gconf_set_string(conf, *keyp, *valp, &err))
+          if (!gconf_engine_set_string(conf, *keyp, *valp, &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%s': %s\n",
-                      *keyp, *valp, err->str);
-              gconf_error_destroy(err);
+                      *keyp, *valp, err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_string(conf, *keyp, &err);
+              gotten = gconf_engine_get_string(conf, *keyp, &err);
               
               if (err != NULL)
                 {
                   check(gotten == NULL, "string was returned though there was an error");
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -254,24 +254,24 @@ check_string_storage(GConfEngine* conf)
         {
           gchar* gotten;
           
-          if (!gconf_set_string(conf, *keyp, *valp, &err))
+          if (!gconf_engine_set_string(conf, *keyp, *valp, &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%s': %s\n",
-                      *keyp, *valp, err->str);
-              gconf_error_destroy(err);
+                      *keyp, *valp, err->message);
+              g_error_free(err);
               err = NULL;
             }
 
           sync_and_clear(conf);
           
-          gotten = gconf_get_string(conf, *keyp, &err);
+          gotten = gconf_engine_get_string(conf, *keyp, &err);
 
           if (err != NULL)
             {
               check(gotten == NULL, "string was returned though there was an error");
               fprintf(stderr, "Failed to get key `%s': %s\n",
-                      *keyp, err->str);
-              gconf_error_destroy(err);
+                      *keyp, err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
@@ -295,7 +295,7 @@ check_string_storage(GConfEngine* conf)
 void
 check_bool_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   guint i; 
   
@@ -310,26 +310,26 @@ check_bool_storage(GConfEngine* conf)
         {
           gboolean gotten;
           
-          if (!gconf_set_bool(conf, *keyp, bools[i], &err))
+          if (!gconf_engine_set_bool(conf, *keyp, bools[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%d': %s\n",
-                      *keyp, bools[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, bools[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_bool(conf, *keyp, &err);
+              gotten = gconf_engine_get_bool(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == FALSE, "TRUE was returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -358,26 +358,26 @@ check_bool_storage(GConfEngine* conf)
         {
           gboolean gotten;
           
-          if (!gconf_set_bool(conf, *keyp, bools[i], &err))
+          if (!gconf_engine_set_bool(conf, *keyp, bools[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%d': %s\n",
-                      *keyp, bools[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, bools[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_bool(conf, *keyp, &err);
+              gotten = gconf_engine_get_bool(conf, *keyp, &err);
               
               if (err != NULL)
                 {
                   check(gotten == FALSE, "TRUE was returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -400,7 +400,7 @@ check_bool_storage(GConfEngine* conf)
 void
 check_float_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   guint i; 
   const gdouble tolerance = 1e-5;
@@ -416,26 +416,26 @@ check_float_storage(GConfEngine* conf)
         {
           gdouble gotten;
           
-          if (!gconf_set_float(conf, *keyp, floats[i], &err))
+          if (!gconf_engine_set_float(conf, *keyp, floats[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%g': %s\n",
-                      *keyp, floats[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, floats[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_float(conf, *keyp, &err);
+              gotten = gconf_engine_get_float(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == 0.0, "0.0 not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -465,26 +465,26 @@ check_float_storage(GConfEngine* conf)
         {
           gdouble gotten;
           
-          if (!gconf_set_float(conf, *keyp, floats[i], &err))
+          if (!gconf_engine_set_float(conf, *keyp, floats[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%g': %s\n",
-                      *keyp, floats[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, floats[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_float(conf, *keyp, &err);
+              gotten = gconf_engine_get_float(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == 0.0, "0.0 not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -509,7 +509,7 @@ check_float_storage(GConfEngine* conf)
 void
 check_int_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   guint i; 
   
@@ -524,26 +524,26 @@ check_int_storage(GConfEngine* conf)
         {
           gint gotten;
           
-          if (!gconf_set_int(conf, *keyp, ints[i], &err))
+          if (!gconf_engine_set_int(conf, *keyp, ints[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%d': %s\n",
-                      *keyp, ints[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, ints[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_int(conf, *keyp, &err);
+              gotten = gconf_engine_get_int(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == 0.0, "0.0 not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -573,26 +573,26 @@ check_int_storage(GConfEngine* conf)
         {
           gint gotten;
           
-          if (!gconf_set_int(conf, *keyp, ints[i], &err))
+          if (!gconf_engine_set_int(conf, *keyp, ints[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%d': %s\n",
-                      *keyp, ints[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, ints[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_int(conf, *keyp, &err);
+              gotten = gconf_engine_get_int(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == 0, "0 not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -760,7 +760,7 @@ list_of_floats(void)
 static void
 check_list_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   guint i;
   GConfValueType list_types[] = { GCONF_VALUE_INT, GCONF_VALUE_INT,
@@ -800,26 +800,26 @@ check_list_storage(GConfEngine* conf)
         {
           GSList* gotten = NULL;
           
-          if (!gconf_set_list(conf, *keyp, list_types[i], lists[i], &err))
+          if (!gconf_engine_set_list(conf, *keyp, list_types[i], lists[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to list: %s\n",
-                      *keyp, err->str);
-              gconf_error_destroy(err);
+                      *keyp, err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
               sync_and_clear(conf);
               
-              gotten = gconf_get_list(conf, *keyp, list_types[i], &err);
+              gotten = gconf_engine_get_list(conf, *keyp, list_types[i], &err);
 
               if (err != NULL)
                 {
                   check(gotten == NULL, "NULL not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -848,14 +848,14 @@ int
 main (int argc, char** argv)
 {
   GConfEngine* conf;
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (!gconf_init(argc, argv, &err))
     {
       g_assert(err != NULL);
-      fprintf(stderr, "Failed to init GConf: %s\n", err->str);
+      fprintf(stderr, "Failed to init GConf: %s\n", err->message);
       fflush(stderr);
-      gconf_error_destroy(err);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
