@@ -78,19 +78,19 @@ static const guint n_ints = sizeof(ints)/sizeof(ints[0]);
 static void
 check_unset(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
 
   keyp = keys;
 
   while (*keyp)
     {
-      gconf_unset(conf, *keyp, &err);
+      gconf_engine_unset(conf, *keyp, &err);
 
       if (err != NULL)
         {
-          fprintf(stderr, "unset of `%s' failed: %s\n", *keyp, err->str);
-          gconf_error_destroy(err);
+          fprintf(stderr, "unset of `%s' failed: %s\n", *keyp, err->message);
+          g_error_free(err);
           err = NULL;
         }
       else
@@ -98,7 +98,7 @@ check_unset(GConfEngine* conf)
           GConfValue* val;
           gchar* valstr;
           
-          val = gconf_get(conf, *keyp, &err);
+          val = gconf_engine_get (conf, *keyp, &err);
 
 
           if (val)
@@ -118,7 +118,7 @@ check_unset(GConfEngine* conf)
 void
 check_int_storage(GConfEngine* conf)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   const gchar** keyp = NULL;
   guint i; 
   
@@ -133,24 +133,24 @@ check_int_storage(GConfEngine* conf)
         {
           gint gotten;
           
-          if (!gconf_set_int(conf, *keyp, ints[i], &err))
+          if (!gconf_engine_set_int(conf, *keyp, ints[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%d': %s\n",
-                      *keyp, ints[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, ints[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
-              gotten = gconf_get_int(conf, *keyp, &err);
+              gotten = gconf_engine_get_int(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == 0.0, "0.0 not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -180,24 +180,24 @@ check_int_storage(GConfEngine* conf)
         {
           gint gotten;
           
-          if (!gconf_set_int(conf, *keyp, ints[i], &err))
+          if (!gconf_engine_set_int(conf, *keyp, ints[i], &err))
             {
               fprintf(stderr, "Failed to set key `%s' to `%d': %s\n",
-                      *keyp, ints[i], err->str);
-              gconf_error_destroy(err);
+                      *keyp, ints[i], err->message);
+              g_error_free(err);
               err = NULL;
             }
           else
             {
-              gotten = gconf_get_int(conf, *keyp, &err);
+              gotten = gconf_engine_get_int(conf, *keyp, &err);
 
               if (err != NULL)
                 {
                   check(gotten == 0, "0 not returned though there was an error");
 
                   fprintf(stderr, "Failed to get key `%s': %s\n",
-                          *keyp, err->str);
-                  gconf_error_destroy(err);
+                          *keyp, err->message);
+                  g_error_free(err);
                   err = NULL;
                 }
               else
@@ -235,68 +235,68 @@ null_safe_strcmp(const char* lhs, const char* rhs)
 void
 check_one_schema(GConfEngine* conf, const gchar** keyp, GConfSchema* schema)
 {
-  GConfError* err = NULL;
+  GError* err = NULL;
   
-  if (!gconf_set_schema(conf, *keyp, schema, &err))
+  if (!gconf_engine_set_schema(conf, *keyp, schema, &err))
     {
       fprintf(stderr, "Failed to set key `%s' to schema: %s\n",
-              *keyp, err->str);
-      gconf_error_destroy(err);
+              *keyp, err->message);
+      g_error_free(err);
       err = NULL;
     }
   else
     {
       GConfSchema* gotten;
       
-      gotten = gconf_get_schema(conf, *keyp, &err);
+      gotten = gconf_engine_get_schema(conf, *keyp, &err);
 
       if (err != NULL)
         {
           check(gotten == NULL, "NULL not returned though there was an error");
 
           fprintf(stderr, "Failed to get key `%s': %s\n",
-                  *keyp, err->str);
-          gconf_error_destroy(err);
+                  *keyp, err->message);
+          g_error_free(err);
           err = NULL;
         }
       else
         {
-          check (gconf_schema_type(schema) == gconf_schema_type(gotten),
+          check (gconf_schema_get_type(schema) == gconf_schema_get_type(gotten),
                  "schema set/get pair: type `%s' set, `%s' got",
-                 gconf_value_type_to_string(gconf_schema_type(schema)),
-                 gconf_value_type_to_string(gconf_schema_type(gotten)));
+                 gconf_value_type_to_string(gconf_schema_get_type(schema)),
+                 gconf_value_type_to_string(gconf_schema_get_type(gotten)));
 
 
           /* If we set the schema for the current locale be sure we get it back */
-          if (null_safe_strcmp(gconf_current_locale(), gconf_schema_locale(schema)) == 0)
+          if (null_safe_strcmp(gconf_current_locale(), gconf_schema_get_locale(schema)) == 0)
             {
-              check (null_safe_strcmp(gconf_current_locale(), gconf_schema_locale(gotten)) == 0,
+              check (null_safe_strcmp(gconf_current_locale(), gconf_schema_get_locale(gotten)) == 0,
                      "schema set/get pair: locale `%s' set, `%s' got",
                      gconf_current_locale(),
-                     gconf_schema_locale(gotten));
+                     gconf_schema_get_locale(gotten));
             }
               
-          check (null_safe_strcmp(gconf_schema_short_desc(schema), gconf_schema_short_desc(gotten)) == 0,
+          check (null_safe_strcmp(gconf_schema_get_short_desc(schema), gconf_schema_get_short_desc(gotten)) == 0,
                  "schema set/get pair: short_desc `%s' set, `%s' got",
-                 gconf_schema_short_desc(schema),
-                 gconf_schema_short_desc(gotten));
+                 gconf_schema_get_short_desc(schema),
+                 gconf_schema_get_short_desc(gotten));
 
-          check (null_safe_strcmp(gconf_schema_long_desc(schema), gconf_schema_long_desc(gotten)) == 0,
+          check (null_safe_strcmp(gconf_schema_get_long_desc(schema), gconf_schema_get_long_desc(gotten)) == 0,
                  "schema set/get pair: long_desc `%s' set, `%s' got",
-                 gconf_schema_long_desc(schema),
-                 gconf_schema_long_desc(gotten));
+                 gconf_schema_get_long_desc(schema),
+                 gconf_schema_get_long_desc(gotten));
 
-          check (null_safe_strcmp(gconf_schema_owner(schema), gconf_schema_owner(gotten)) == 0,
+          check (null_safe_strcmp(gconf_schema_get_owner(schema), gconf_schema_get_owner(gotten)) == 0,
                  "schema set/get pair: owner `%s' set, `%s' got",
-                 gconf_schema_owner(schema),
-                 gconf_schema_owner(gotten));
+                 gconf_schema_get_owner(schema),
+                 gconf_schema_get_owner(gotten));
 
           {
             GConfValue* set_default;
             GConfValue* got_default;
 
-            set_default = gconf_schema_default_value(schema);
-            got_default = gconf_schema_default_value(gotten);
+            set_default = gconf_schema_get_default_value(schema);
+            got_default = gconf_schema_get_default_value(gotten);
 
             if (set_default && got_default)
               {
@@ -313,9 +313,9 @@ check_one_schema(GConfEngine* conf, const gchar** keyp, GConfSchema* schema)
                       gconf_value_type_to_string(set_default->type),
                       gconf_value_type_to_string(got_default->type));
                 
-                check(gconf_value_int(set_default) == gconf_value_int(got_default),
+                check(gconf_value_get_int(set_default) == gconf_value_get_int(got_default),
                       "schema set/get pair: default value (int) `%d' set, `%d' got",
-                      gconf_value_int(set_default), gconf_value_int(got_default));
+                      gconf_value_get_int(set_default), gconf_value_get_int(got_default));
               }
             else
               {
@@ -327,7 +327,7 @@ check_one_schema(GConfEngine* conf, const gchar** keyp, GConfSchema* schema)
               }
           }
           
-          gconf_schema_destroy(gotten);
+          gconf_schema_free(gotten);
         }
     }
 }
@@ -377,12 +377,12 @@ check_schema_storage(GConfEngine* conf)
           
           gconf_schema_set_default_value_nocopy(schema, default_value);
 
-          check(gconf_value_int(gconf_schema_default_value(schema)) == default_value_int,
+          check(gconf_value_get_int(gconf_schema_get_default_value(schema)) == default_value_int,
                 "Properly stored default int value in the schema");
           
           check_one_schema(conf, keyp, schema);
 
-          gconf_schema_destroy(schema);
+          gconf_schema_free(schema);
           g_free(long_desc);
           g_free(short_desc);
           
@@ -413,7 +413,7 @@ check_schema_storage(GConfEngine* conf)
 
           check_one_schema(conf, keyp, schema);
 
-          gconf_schema_destroy(schema);
+          gconf_schema_free(schema);
           
           ++i;
         }
@@ -430,12 +430,12 @@ int
 main (int argc, char** argv)
 {
   GConfEngine* conf;
-  GConfError* err = NULL;
+  GError* err = NULL;
   
   if (!gconf_init(argc, argv, &err))
     {
-      fprintf(stderr, "Failed to init GConf: %s\n", err->str);
-      gconf_error_destroy(err);
+      fprintf(stderr, "Failed to init GConf: %s\n", err->message);
+      g_error_free(err);
       err = NULL;
       return 1;
     }
